Print a graph showing significant correlations between survey items
fig_LID(
LIDforgraph,
LIDcutoff = 0.2,
path_output,
extra_file_label = NULL,
vertex_print_grey = NULL
)Returns a ggplot graph showing the items with correlation >= LIDcutoff and prints a csv of the corresponding correlations
a square matrix of item correlations
a numeric value between 0 and 1 for the cut-off for significant correlation
a string with the path to the output folder
a string to tack on to the end of names of files outputted and the title of the plot. Default is NULL.
a character vector with the names of vertices to print in "lightgrey", with all others printed in "skyblue". If left as default NULL, all vertices will be printed in "lightgrey".
This function could be applied to visualize any kind of correlations. But within the context of the Rasch Analysis used for the WHO Model Disability Survey, the residual correlations are used when analyzing item dependence.
Other figure functions:
fig_density(),
fig_dist(),
fig_poppyramid()