Learn R Programming

whomds (version 1.1.1)

helper_installation: Check installation of whomds is the most updated

Description

Compares build date of installed package against the date of the last commit from GitHub (https://github.com/lindsayevanslee/whomds)

Usage

helper_installation()

Arguments

Value

Prints a message stating whether or not installed package is same as most updated version from Github