Color palette for the MDS
helper_palette(
n,
h = c(-100, 100),
c. = c(60, 100),
l = c(15, 95),
power = c(2, 0.9),
fixup = TRUE,
gamma = NULL,
alpha = 1,
...
)n hex codes from the color palette
the number of colors (\(\ge 1\)) to be in the palette.
hue value in the HCL or HSV color description, has to be in [0, 360] for HCL and in [0, 1] for HSV colors.
chroma value in the HCL color description.
luminance value in the HCL color description.
control parameter determining how chroma and luminance should be increased (1 = linear, 2 = quadratic, etc.).
logical. Should the color be corrected to a valid RGB value before correction?
Deprecated.
numeric vector of values in the range [0, 1] for alpha
transparency channel (0 means transparent and 1 means opaque).
Other arguments passed to hex.
Generated with colorspace::choose_palette()
Other helper functions:
helper_checkrow(),
helper_varslist()