Drop items from a Rasch Analysis
rasch_drop(vars_metric, drop_vars, max_values)a named list with:
new vars_metric after dropping the desired variables
new max_values after dropping the desired variables
a character vector of items to use in the Rasch Analysis
a character vector of column names to drop from the Rasch Analysis. Default is NULL, to not drop items.
a tibble with two columns, var equivalent to vars_metric and max_val with their corresponding maximum possible values
Dropping variables might be desirable if one finds that particular items are causing a lot of problems for the fit of a Rasch Model.
Other rasch functions:
rasch_DIF(),
rasch_df_nest(),
rasch_factor(),
rasch_mds_children(),
rasch_mds(),
rasch_model_children(),
rasch_model(),
rasch_quality_children_print(),
rasch_quality_children(),
rasch_rawscore(),
rasch_recode(),
rasch_rescale_children(),
rasch_rescale(),
rasch_split_age(),
rasch_split(),
rasch_testlet()
Other children analysis functions:
rasch_df_nest(),
rasch_mds_children(),
rasch_model_children(),
rasch_quality_children_print(),
rasch_quality_children(),
rasch_recode(),
rasch_rescale_children(),
rasch_split_age(),
rasch_split(),
rasch_testlet()