Run the multigroup and anchored Rasch Model
rasch_model_children(df, df_nest, vars_metric, vars_group, TAM_model)a nested tibble with new columns with the Rasch Models calculated with the TAM package
a data frame of individual survey data, where each row is an individual
a nested tibble that contains the column df_split with the data split by the categories in the column vars_group
a character vector of items to use in the Rasch Analysis
a string with the column name identifying grouping variable
a string with the type of IRT model to use, passed to irtmodel argument of TAM::tam(). Default is "PCM2"
Other rasch functions:
rasch_DIF(),
rasch_df_nest(),
rasch_drop(),
rasch_factor(),
rasch_mds_children(),
rasch_mds(),
rasch_model(),
rasch_quality_children_print(),
rasch_quality_children(),
rasch_rawscore(),
rasch_recode(),
rasch_rescale_children(),
rasch_rescale(),
rasch_split_age(),
rasch_split(),
rasch_testlet()
Other children analysis functions:
rasch_df_nest(),
rasch_drop(),
rasch_mds_children(),
rasch_quality_children_print(),
rasch_quality_children(),
rasch_recode(),
rasch_rescale_children(),
rasch_split_age(),
rasch_split(),
rasch_testlet()