Calculate quality of multigroup and anchored Rasch Models
rasch_quality_children(df_nest, vars_metric)a nested tibble with new columns with information about model quality
a nested tibble that contains the column df_split with the data split by the categories in the column vars_group
a character vector of items to use in the Rasch Analysis
Other rasch functions:
rasch_DIF(),
rasch_df_nest(),
rasch_drop(),
rasch_factor(),
rasch_mds_children(),
rasch_mds(),
rasch_model_children(),
rasch_model(),
rasch_quality_children_print(),
rasch_rawscore(),
rasch_recode(),
rasch_rescale_children(),
rasch_rescale(),
rasch_split_age(),
rasch_split(),
rasch_testlet()
Other children analysis functions:
rasch_df_nest(),
rasch_drop(),
rasch_mds_children(),
rasch_model_children(),
rasch_quality_children_print(),
rasch_recode(),
rasch_rescale_children(),
rasch_split_age(),
rasch_split(),
rasch_testlet()