Rescale score from Rasch Analysis to range from 0 to 100
rasch_rescale(df, df_score, vars_id)a tibble with the left join between df and df_score and new column "rescaled" with the rescaled person abilities, ranging from 0 to 100, and filter out any rows with an artificial minimum or maximum
a data frame of individual survey data, where each row is an individual
a tibble resulting from rasch_model() with the person abilities from the Rasch Model
a string with column name uniquely identifying individuals
Other rasch functions:
rasch_DIF(),
rasch_df_nest(),
rasch_drop(),
rasch_factor(),
rasch_mds_children(),
rasch_mds(),
rasch_model_children(),
rasch_model(),
rasch_quality_children_print(),
rasch_quality_children(),
rasch_rawscore(),
rasch_recode(),
rasch_rescale_children(),
rasch_split_age(),
rasch_split(),
rasch_testlet()