powered by
Compares build date of installed package against the date of the last commit from GitHub (https://github.com/lindsayevanslee/whomds)
helper_installation()
Prints a message stating whether or not installed package is same as most updated version from Github